<?php

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    WC_Expapay_Payment_Gateway
 * @subpackage WC_Expapay_Payment_Gateway/includes
 */
class WC_Expapay_Payment_Gateway {
	
	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      WC_Expapay_Payment_Gateway_Loader $loader Maintains and registers all hooks for the plugin.
	 */
	protected $loader;
	
	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string $plugin_name The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;
	
	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string $version The current version of the plugin.
	 */
	protected $version;
	
	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'WC_EXPAPAY_PAYMENT_GATEWAY_VERSION' ) ) {
			$this->version = WC_EXPAPAY_PAYMENT_GATEWAY_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'woocommerce-expapay-payment-gateway';
		
		$this->load_dependencies();
		$this->set_gateway_loaded();
	}
	
	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - WC_Expapay_Payment_Gateway_Loader. Orchestrates the hooks of the plugin.
	 * - WC_Expapay_Payment_Gateway_i18n. Defines internationalization functionality.
	 * - WC_Expapay_Payment_Gateway_Admin. Defines all hooks for the admin area.
	 * - WC_Expapay_Payment_Gateway_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {
		
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wc-expapay-payment-gateway-loader.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'woocommerce/class-wc-expapay-payment-gateway-loaded.php';
		
		$this->loader = new WC_Expapay_Payment_Gateway_Loader();
	}
	
	
	private function set_gateway_loaded() {
		
		$plugin_gateway = new WC_Expapay_Payment_Gateway_loaded();
		
		$this->loader->add_filter( 'woocommerce_payment_gateways', $plugin_gateway, 'add_gateway_class' );
		$this->loader->add_action( 'plugins_loaded', $plugin_gateway, 'init_gateway_class' );
	}
	
	
	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}
	
	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @return    string    The name of the plugin.
	 * @since     1.0.0
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}
	
	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @return    WC_Expapay_Payment_Gateway_Loader    Orchestrates the hooks of the plugin.
	 * @since     1.0.0
	 */
	public function get_loader() {
		return $this->loader;
	}
	
	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @return    string    The version number of the plugin.
	 * @since     1.0.0
	 */
	public function get_version() {
		return $this->version;
	}
	
}
